#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_IMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_IMAG_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/simd/is_not_imag.hpp>

#endif
